<?php

namespace SGalinski\SgJobs\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Database\ConnectionPool;
use TYPO3\CMS\Core\Database\DatabaseConnection;
use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
use TYPO3\CMS\Core\Database\Query\Restriction\FrontendRestrictionContainer;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Persistence\Repository;

/**
 * Company Repository
 */
class CompanyRepository extends Repository {

	const TABLENAME = 'tx_sgjobs_domain_model_company';

	/**
	 * initializes the object
	 */
	public function initializeObject() {
		$querySettings = $this->createQuery()->getQuerySettings();
		$querySettings->setRespectStoragePage(FALSE);
		$querySettings->setIgnoreEnableFields(TRUE);
		$querySettings->setEnableFieldsToBeIgnored(['disabled']);
		$this->setDefaultQuerySettings($querySettings);
	}

	/**
	 * Returns all countries filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCountries($pageUid) {
		$queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable(
			'tx_sgjobs_domain_model_job'
		);

		$queryBuilder
			->getRestrictions()
			->removeAll()
			->add(GeneralUtility::makeInstance(DeletedRestriction::class))
			->add(GeneralUtility::makeInstance(FrontendRestrictionContainer::class));
		$statement = $queryBuilder->select('country')->from('tx_sgjobs_domain_model_company');

		$statement->where(
			$queryBuilder->expr()->eq(
				'pid', $queryBuilder->createNamedParameter($pageUid)
			)
		);

		$result = $statement->execute()->fetchAll();
		$countryArray = [''];
		foreach ($result as $country) {
			$countryArray[$country['country']] = $country['country'];
		}

		return $countryArray;
	}

	/**
	 * Returns all filtered cities
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCities($pageUid) {
		$queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable(
			self::TABLENAME
		);

		$queryBuilder
			->getRestrictions()
			->removeAll()
			->add(GeneralUtility::makeInstance(DeletedRestriction::class))
			->add(GeneralUtility::makeInstance(FrontendRestrictionContainer::class));
		$statement = $queryBuilder->select('city')->from('tx_sgjobs_domain_model_company');

		$statement->where(
			$queryBuilder->expr()->eq(
				'pid', $queryBuilder->createNamedParameter($pageUid)
			)
		);

		$result = $statement->execute()->fetchAll();
		$cityArray = [''];
		foreach ($result as $city) {
			$cityArray[$city['city']] = $city['city'];
		}

		return $cityArray;
	}

	/**
	 * Returns all companies filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 * @throws \InvalidArgumentException
	 */
	public function getAllCompanyNames($pageUid) {
		$queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable(
			self::TABLENAME
		);

		$queryBuilder
			->getRestrictions()
			->removeAll()
			->add(GeneralUtility::makeInstance(DeletedRestriction::class))
			->add(GeneralUtility::makeInstance(FrontendRestrictionContainer::class));
		$statement = $queryBuilder->select('name')->from('tx_sgjobs_domain_model_company');

		$statement->where(
			$queryBuilder->expr()->eq(
				'pid', $queryBuilder->createNamedParameter($pageUid)
			)
		);

		$result = $statement->execute()->fetchAll();

		$namesArray = [''];
		foreach ($result as $name) {
			$namesArray[$name['name']] = $name['name'];
		}

		return $namesArray;
	}
}
